package com.ruoyi.biz.controller;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import com.ruoyi.biz.domain.bo.ArUserBo;
import com.ruoyi.biz.domain.vo.ArUserVo;
import com.ruoyi.biz.service.IArUserService;
import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户
 *
 * @author ruoyi
 * @date 2023-06-27
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/biz/user")
public class ArUserController extends BaseController {

    private final IArUserService iArUserService;

    /**
     * 查询用户列表
     */
    @SaCheckPermission("system:user:list")
    @GetMapping("/list")
    public TableDataInfo<ArUserVo> list(ArUserBo bo, PageQuery pageQuery) {
        return iArUserService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出用户列表
     */
    @SaCheckPermission("system:user:export")
    @Log(title = "用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ArUserBo bo, HttpServletResponse response) {
        List<ArUserVo> list = iArUserService.queryList(bo);
        ExcelUtil.exportExcel(list, "用户", ArUserVo.class, response);
    }

    /**
     * 获取用户详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("system:user:query")
    @GetMapping("/{id}")
    public R<ArUserVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iArUserService.queryById(id));
    }

    /**
     * 新增用户
     */
    @SaCheckPermission("system:user:add")
    @Log(title = "用户", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ArUserBo bo) {
        return toAjax(iArUserService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改用户
     */
    @SaCheckPermission("system:user:edit")
    @Log(title = "用户", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ArUserBo bo) {
        return toAjax(iArUserService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除用户
     *
     * @param ids 主键串
     */
    @SaCheckPermission("system:user:remove")
    @Log(title = "用户", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iArUserService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }
}
